@@ -14,20 +14,21 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
+
+#include "seahorse-pkcs11-backend.h"
+
+#include "seahorse-pkcs11-generate.h"
+
+#include "pkcs11/seahorse-pkcs11.h"
+
 #include "seahorse-common.h"
 
-#include "seahorse-pkcs11.h"
-#include "seahorse-pkcs11-backend.h"
-#include "seahorse-pkcs11-generate.h"
-#include "seahorse-token.h"
-
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <gcr/gcr-base.h>
 
@@ -145,7 +146,7 @@ on_initialized_registered (GObject *unused,
 			if (token == NULL)
 				continue;
 			if (is_token_usable (self, s->data, token)) {
-				place = SEAHORSE_PLACE (seahorse_token_new (s->data));
+				place = SEAHORSE_PLACE (seahorse_pkcs11_token_new (s->data));
 				self->tokens = g_list_append (self->tokens, place);
 				gcr_collection_emit_added (GCR_COLLECTION (self), G_OBJECT (place));
 			}
@@ -308,7 +309,7 @@ seahorse_pkcs11_backend_lookup_place (SeahorseBackend *backend,
 		return NULL;
 
 	for (l = self->tokens; l != NULL; l = g_list_next (l)) {
-		if (gck_slot_match (seahorse_token_get_slot (l->data), uri_data))
+		if (gck_slot_match (seahorse_pkcs11_token_get_slot (l->data), uri_data))
 			break;
 	}
 
@@ -351,18 +352,18 @@ static gboolean
 on_filter_writable (GObject *object,
                     gpointer user_data)
 {
-	SeahorseToken *token = SEAHORSE_TOKEN (object);
+	SeahorsePkcs11Token *token = SEAHORSE_PKCS11_TOKEN (object);
 	guint mechanism = GPOINTER_TO_UINT (user_data);
 	GckTokenInfo *info;
 
-	info = seahorse_token_get_info (token);
+	info = seahorse_pkcs11_token_get_info (token);
 	g_return_val_if_fail (info != NULL, FALSE);
 
 	if (info->flags & CKF_WRITE_PROTECTED)
 		return FALSE;
 
 	if (mechanism != G_MAXUINT) {
-		if (!seahorse_token_has_mechanism (token, (gulong)mechanism))
+		if (!seahorse_pkcs11_token_has_mechanism (token, (gulong)mechanism))
 			return FALSE;
 	}
 
